@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 
+from .acl import ACL
 from .acm import ACM
 from .arxiv import Arxiv
 from .citeseerx import CiteSeerX
@@ -15,12 +16,14 @@ from .pdf_url import PdfUrl
 from .pmlr import PMLR
 from .pubmed import PubMed
 from .sagepub import SagePub
+from .science_direct import ScienceDirect
 from .semantic_scholar import SemanticScholar
 from .springer import Springer
 from .tandfonline import TandFOnline
 
 # NOTE: Order matters here, PdfUrl and HTML should be last
 providers = [
+    ACL,
     ACM,
     Arxiv,
     CiteSeerX,
@@ -33,6 +36,7 @@ providers = [
     PMLR,
     PubMed,
     SagePub,
+    ScienceDirect,
     Springer,
     SemanticScholar,
     TandFOnline,
