@@ -19,7 +19,6 @@ import titlecase
 import unidecode
 import urllib
 import weasyprint
-import weasyprint.fonts
 
 from ._base import Provider
 from ._info import Informer
@@ -34,7 +33,6 @@ from ..log import Logger
 logger = Logger()
 
 CSS = """
-@import url('https://fonts.googleapis.com/css?family=EB+Garamond|Noto+Serif|Inconsolata&display=swap');
 @page { size: 702px 936px; margin: 1in; }
 a { color: black; }
 img { display: block; margin: 0 auto; text-align: center; max-width: 70%; max-height: 300px; }
@@ -48,6 +46,13 @@ pre { font-family: 'Inconsolata'; padding-left: 2.5%; background: #efefef; }
 code { font-family: 'Inconsolata'; font-size: .7rem; background: #efefef; }
 """
 
+# NOTE: For some reason, Weasyprint no longer accepts the @import statement in
+# the CSS to load the fonts. This may have to do with recent changes they've
+# introduced. Providing the font urls separately does seem to work.
+FONT_URLS = [
+    "https://fonts.googleapis.com/css2?family=EB+Garamond&family=Noto+Serif&family=Inconsolata"
+]
+
 
 def url_fetcher(url):
     if url.startswith("//"):
@@ -140,7 +145,8 @@ class HTML(Provider):
 
         # This attempts to fix sites where the image src element points to a
         # placeholder and the data-src attribute contains the url to the actual
-        # image.
+        # image. Note that results may differ between readability and
+        # Readability.JS
         regex = '<img src="(?P<src>.*?)" (?P<rest1>.*) data-src="(?P<datasrc>.*?)" (?P<rest2>.*?)>'
         sub = '<img src="\g<datasrc>" \g<rest1> \g<rest2>>'
 
@@ -193,11 +199,11 @@ class HTML(Provider):
             with open("./paper.html", "w") as fp:
                 fp.write(html_article)
 
-        font_config = weasyprint.fonts.FontConfiguration()
         html = weasyprint.HTML(string=html_article, url_fetcher=url_fetcher)
-        css = weasyprint.CSS(string=CSS, font_config=font_config)
-
-        html.write_pdf(filename, stylesheets=[css], font_config=font_config)
+        css = CSS if self.css is None else self.css
+        font_urls = FONT_URLS if self.font_urls is None else self.font_urls
+        style = weasyprint.CSS(string=css)
+        html.write_pdf(filename, stylesheets=[style] + font_urls)
 
     def validate(src):
         # first check if it is a valid url
